@@ -105,60 +105,10 @@ map_query_to_nodal_type <-  function(model, query, join_by = "|") {
                         evaluated_nodes = t(eval(parse(text = node))),
                         node = node)
 
-    class(return_list) <- "nodal_types_query"
     return(return_list)
-
 }
 
 
-#' @export
-print.nodal_types_query <- function(x, ...) {
-  if (length(unique(x$types)) > 2) {
-    cat(
-      paste(
-        "\n\n Caution: This appears to be a complex query reporting",
-        "coefficients on types and not simply identifying types\n\n"
-      )
-    )
-  }
-
-  output_type <- class(x$types)
-
-  types_labels <- names(x$types)[x$types != 0]
-  nt <- length(types_labels)
-  cat(paste("\nNodal types adding weight to query"))
-
-  if (x$query != x$expanded_query) {
-    cat(paste("\n\n query : ", x$expanded_query, "\n\n"))
-  } else {
-    cat(paste("\n\n query : ", x$query, "\n\n"))
-  }
-
-  if (length(types_labels) %% 2 != 0) {
-    types_labels[length(types_labels) + 1] <- ""
-  }
-  counter <- 2
-  while (counter <= length(types_labels)) {
-    cat(paste0(" ", types_labels[(counter - 1):counter], collapse = "  "))
-    cat("\n")
-    counter <- counter + 2
-  }
-
-  cat(paste(
-    "\n\n Number of nodal types that add weight to query =",
-    nt))
-
-  cat(paste(
-    "\n Total number of nodal types related to",
-    x$node,
-    "=",
-    length(x$types)
-  ))
-  invisible(x)
-}
-
-
-
 #' Helper to fill in missing do operators in causal expression
 #' @inheritParams CausalQueries_internal_inherit_params
 #' @param q A character string. Causal query with at least one parent node
